@@ -1,4 +1,5 @@
 # Copyright 2015-2016, Tresys Technology, LLC
+# Copyright 2018, Chris PeBenito <pebenito@ieee.org>
 #
 # This file is part of SETools.
 #
@@ -16,13 +17,35 @@
 # License along with SETools.  If not, see
 # <http://www.gnu.org/licenses/>.
 #
+from collections import defaultdict
+
 from .difference import Wrapper
 
 
-class ConditionalExprWrapper(Wrapper):
+_cond_cache = defaultdict(dict)
+
+
+def conditional_wrapper_factory(cond):
+    """
+    Wrap type attributes from the specified policy.
+
+    This caches results to prevent duplicate wrapper
+    objects in memory.
+    """
+    try:
+        return _cond_cache[cond.policy][cond]
+    except KeyError:
+        a = ConditionalWrapper(cond)
+        _cond_cache[cond.policy][cond] = a
+        return a
+
+
+class ConditionalWrapper(Wrapper):
 
     """Wrap conditional policy expressions to allow comparisons by truth table."""
 
+    __slots__ = ("truth_table")
+
     def __init__(self, cond):
         self.origin = cond
         self.truth_table = cond.truth_table()
