@@ -19,21 +19,26 @@
 
 import logging
 import copy
+from collections import defaultdict
+from contextlib import suppress
 
 from PyQt5.QtCore import pyqtSignal, Qt, QStringListModel, QThread
 from PyQt5.QtGui import QPalette, QTextCursor
-from PyQt5.QtWidgets import QCompleter, QHeaderView, QMessageBox, QProgressDialog, QScrollArea, \
-                            QTreeWidgetItem
+from PyQt5.QtWidgets import QCompleter, QHeaderView, QMessageBox, QProgressDialog, \
+    QTreeWidgetItem
 from setools import InfoFlowAnalysis
 from setools.exception import UnmappedClass, UnmappedPermission
 
 from ..logtosignal import LogHandlerToSignal
-from ..widget import SEToolsWidget
+from .analysistab import AnalysisTab
+from .exception import TabFieldError
 from .excludetypes import ExcludeTypes
 from .permmapedit import PermissionMapEditor
+from .workspace import load_checkboxes, load_spinboxes, load_lineedits, load_textedits, \
+    save_checkboxes, save_spinboxes, save_lineedits, save_textedits
 
 
-class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
+class InfoFlowAnalysisTab(AnalysisTab):
 
     """An information flow analysis tab."""
 
@@ -51,10 +56,8 @@ class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
         # current permission map, to the new map
         for classname in self.query.perm_map.classes():
             for mapping in self.query.perm_map.perms(classname):
-                try:
+                with suppress(UnmappedClass, UnmappedPermission):
                     perm_map.mapping(classname, mapping.perm).enabled = mapping.enabled
-                except (UnmappedClass, UnmappedPermission):
-                    pass
 
         # apply updated permission map
         self.query.perm_map = perm_map
@@ -75,7 +78,7 @@ class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
 
     def setupUi(self):
         self.log.debug("Initializing UI.")
-        self.load_ui("infoflow.ui")
+        self.load_ui("apol/infoflow.ui")
 
         # set up error message for missing perm map
         self.error_msg = QMessageBox(self)
@@ -94,6 +97,7 @@ class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
         self.target.setCompleter(self.type_completion)
 
         # setup indications of errors on source/target/default
+        self.errors = set()
         self.orig_palette = self.source.palette()
         self.error_palette = self.source.palette()
         self.error_palette.setColor(QPalette.Base, Qt.red)
@@ -170,14 +174,8 @@ class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
     #
     # Source criteria
     #
-    def set_source_error(self, error_text):
-        self.log.error("Source type error: {0}".format(error_text))
-        self.source.setToolTip("Error: {0}".format(error_text))
-        self.source.setPalette(self.error_palette)
-
     def clear_source_error(self):
-        self.source.setToolTip("The source type of the analysis.")
-        self.source.setPalette(self.orig_palette)
+        self.clear_criteria_error(self.source, "The source type of the analysis.")
 
     def set_source(self):
         try:
@@ -188,19 +186,14 @@ class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
             else:
                 self.query.source = None
         except Exception as ex:
-            self.set_source_error(ex)
+            self.log.error("Source type error: {0}".format(str(ex)))
+            self.set_criteria_error(self.source, ex)
 
     #
     # Target criteria
     #
-    def set_target_error(self, error_text):
-        self.log.error("Target type error: {0}".format(error_text))
-        self.target.setToolTip("Error: {0}".format(error_text))
-        self.target.setPalette(self.error_palette)
-
     def clear_target_error(self):
-        self.target.setToolTip("The target type of the analysis.")
-        self.target.setPalette(self.orig_palette)
+        self.clear_criteria_error(self.target, "The target type of the analysis.")
 
     def set_target(self):
         try:
@@ -211,7 +204,8 @@ class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
             else:
                 self.query.target = None
         except Exception as ex:
-            self.set_target_error(ex)
+            self.log.error("Target type error: {0}".format(str(ex)))
+            self.set_criteria_error(self.target, ex)
 
     #
     # Options
@@ -230,6 +224,54 @@ class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
         # used only by permission map editor
         self.query.perm_map = pmap
 
+    #
+    # Save/Load tab
+    #
+    def save(self):
+        """Return a dictionary of settings."""
+        if self.errors:
+            raise TabFieldError("Field(s) are in error: {0}".
+                                format(" ".join(o.objectName() for o in self.errors)))
+
+        settings = {}
+        save_checkboxes(self, settings, ["criteria_expander", "notes_expander", "all_paths",
+                                         "all_shortest_paths", "flows_in", "flows_out"])
+        save_lineedits(self, settings, ["source", "target"])
+        save_spinboxes(self, settings, ["max_path_length", "limit_paths", "min_perm_weight"])
+        save_textedits(self, settings, ["notes"])
+
+        settings["exclude"] = [str(t) for t in self.query.exclude]
+
+        settings["exclude_perms"] = defaultdict(list)
+        for mapping in self.perm_map:
+            if not mapping.enabled:
+                settings["exclude_perms"][mapping.class_].append(mapping.perm)
+
+        return settings
+
+    def load(self, settings):
+        load_checkboxes(self, settings, ["criteria_expander", "notes_expander", "all_paths",
+                                         "all_shortest_paths", "flows_in", "flows_out"])
+        load_lineedits(self, settings, ["source", "target"])
+        load_spinboxes(self, settings, ["max_path_length", "limit_paths", "min_perm_weight"])
+        load_textedits(self, settings, ["notes"])
+
+        try:
+            self.query.exclude = settings["exclude"]
+        except KeyError:
+            self.log.warning("Excluded types criteria missing from settings file.")
+
+        if "exclude_perms" not in settings:
+            self.log.warning("Excluded permissions missing from settings file.")
+        else:
+            for mapping in self.perm_map:
+                # iterate over the map so that any permission
+                # not in the setting file's exclude list is enabled.
+                try:
+                    mapping.enabled = mapping.perm not in settings["exclude_perms"][mapping.class_]
+                except KeyError:
+                    mapping.enabled = True
+
     #
     # Infoflow browser
     #
@@ -320,11 +362,11 @@ class InfoFlowAnalysisTab(SEToolsWidget, QScrollArea):
         # right now there is only one button.
         fail = False
         if self.source.isEnabled() and not self.query.source:
-            self.set_source_error("A source type is required")
+            self.set_criteria_error(self.source, "A source type is required")
             fail = True
 
         if self.target.isEnabled() and not self.query.target:
-            self.set_target_error("A target type is required.")
+            self.set_criteria_error(self.target, "A target type is required.")
             fail = True
 
         if not self.perm_map:
