@@ -31,7 +31,7 @@ from .analysistab import AnalysisTab
 from .exception import TabFieldError
 from .queryupdater import QueryResultsUpdater
 from .workspace import load_checkboxes, load_lineedits, load_textedits, load_comboboxes, \
-                       save_checkboxes, save_lineedits, save_textedits, save_comboboxes
+    save_checkboxes, save_lineedits, save_textedits, save_comboboxes
 
 
 class PortconQueryTab(AnalysisTab):
@@ -164,8 +164,8 @@ class PortconQueryTab(AnalysisTab):
             if pending_ports:
                 try:
                     ports = [int(i) for i in pending_ports.split("-")]
-                except ValueError:
-                    raise ValueError("Enter a port number or range, e.g. 22 or 6000-6020")
+                except ValueError as ex:
+                    raise ValueError("Enter a port number or range, e.g. 22 or 6000-6020") from ex
 
                 if len(ports) == 2:
                     self.query.ports = ports
