@@ -15,17 +15,24 @@
 # You should have received a copy of the GNU General Public License
 # along with SETools.  If not, see <http://www.gnu.org/licenses/>.
 #
+import os
 import unittest
 
-from setools import SELinuxPolicy, DefaultQuery, DefaultRuletype, DefaultValue
-from setools.policyrep.exception import InvalidClass
+from setools import DefaultQuery, DefaultRuletype, DefaultValue
+from setools.exception import InvalidClass
+
+from .policyrep.util import compile_policy
 
 
 class DefaultQueryTest(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        cls.p = SELinuxPolicy("tests/defaultquery.conf")
+        cls.p = compile_policy("tests/defaultquery.conf")
+
+    @classmethod
+    def tearDownClass(cls):
+        os.unlink(cls.p.path)
 
     def test_000_unset(self):
         """Default query: no criteria."""
