@@ -15,17 +15,24 @@
 # You should have received a copy of the GNU General Public License
 # along with SETools.  If not, see <http://www.gnu.org/licenses/>.
 #
+import os
 import unittest
 from socket import IPPROTO_UDP
 
-from setools import SELinuxPolicy, PortconQuery
+from setools import PortconQuery
+
+from .policyrep.util import compile_policy
 
 
 class PortconQueryTest(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        cls.p = SELinuxPolicy("tests/portconquery.conf")
+        cls.p = compile_policy("tests/portconquery.conf")
+
+    @classmethod
+    def tearDownClass(cls):
+        os.unlink(cls.p.path)
 
     def test_000_unset(self):
         """Portcon query with no criteria"""
