@@ -1,4 +1,5 @@
 # Copyright 2014-2015, Tresys Technology, LLC
+# Copyright 2019, Chris PeBenito <pebenito@ieee.org>
 #
 # This file is part of SETools.
 #
@@ -94,6 +95,13 @@ class TypeQueryTest(unittest.TestCase):
         types = sorted(str(t) for t in q.results())
         self.assertListEqual(["test21t1", "test21t2"], types)
 
+    def test_022_alias_dereference(self):
+        """Type query with alias dereference."""
+        q = TypeQuery(self.p, name="test22alias", alias_deref=True)
+
+        types = sorted(str(t) for t in q.results())
+        self.assertListEqual(["test22"], types)
+
     def test_030_permissive(self):
         """Type query with permissive match"""
         q = TypeQuery(self.p, permissive=True)
